==> haskell-annotated-wl-pprint-0.7.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-annotated-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 annotated-wl-pprint
version:              0.7.0
visibility:           public
id:                   annotated-wl-pprint-0.7.0-GnwGLTLAoUz1b9IARtaRpM
key:                  annotated-wl-pprint-0.7.0-GnwGLTLAoUz1b9IARtaRpM
license:              BSD-3-Clause
maintainer:           david@davidchristiansen.dk
author:               Daan Leijen, David Raymond Christiansen
homepage:             https://github.com/david-christiansen/annotated-wl-pprint
synopsis:             The Wadler/Leijen Pretty Printer, with annotation support
description:
    This is a modified version of wl-pprint, which was based on Wadler'\''s
    paper "A Prettier  Printer".  See the haddocks for full info.  This
    version allows the library user to annotate the text with semantic
    information, which can later be rendered in a variety of ways.

category:             Text
abi:                  9fb66e2923574754ea4671b6bf4ddb2a
exposed:              True
exposed-modules:      Text.PrettyPrint.Annotated.Leijen
import-dirs:          /usr/lib/ghc-8.8.3/site-local/annotated-wl-pprint-0.7.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/annotated-wl-pprint-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/annotated-wl-pprint-0.7.0
hs-libraries:         HSannotated-wl-pprint-0.7.0-GnwGLTLAoUz1b9IARtaRpM
depends:              base-4.13.0.0
haddock-interfaces:
    /usr/share/doc/haskell-annotated-wl-pprint/html/annotated-wl-pprint.haddock

haddock-html:         /usr/share/doc/haskell-annotated-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-annotated-wl-pprint-0.7.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-annotated-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 annotated-wl-pprint
version:              0.7.0
visibility:           public
id:                   annotated-wl-pprint-0.7.0-5AIkoQx8i1025QrzXHJkLX
key:                  annotated-wl-pprint-0.7.0-5AIkoQx8i1025QrzXHJkLX
license:              BSD-3-Clause
maintainer:           david@davidchristiansen.dk
author:               Daan Leijen, David Raymond Christiansen
homepage:             https://github.com/david-christiansen/annotated-wl-pprint
synopsis:             The Wadler/Leijen Pretty Printer, with annotation support
description:
    This is a modified version of wl-pprint, which was based on Wadler'\''s
    paper "A Prettier  Printer".  See the haddocks for full info.  This
    version allows the library user to annotate the text with semantic
    information, which can later be rendered in a variety of ways.

category:             Text
abi:                  21dc15e3fad91a98db74996b9f7795d8
exposed:              True
exposed-modules:      Text.PrettyPrint.Annotated.Leijen
import-dirs:          /usr/lib/ghc-8.10.1/site-local/annotated-wl-pprint-0.7.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/annotated-wl-pprint-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.1/annotated-wl-pprint-0.7.0

hs-libraries:         HSannotated-wl-pprint-0.7.0-5AIkoQx8i1025QrzXHJkLX
depends:              base-4.14.0.0
haddock-interfaces:
    /usr/share/doc/haskell-annotated-wl-pprint/html/annotated-wl-pprint.haddock

haddock-html:         /usr/share/doc/haskell-annotated-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
